<?php
//
// +----------------------------------------------------------------------+
// | PHP Version 5                                                        |
// +----------------------------------------------------------------------+
// | Copyright (c) 1997-2003 The PHP Group                                |
// +----------------------------------------------------------------------+
// | This source file is subject to version 3.0 of the PHP license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available at through the world-wide-web at                           |
// | http://www.php.net/license/3_0.txt.                                  |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
// | Authors: Hartmut Holzgraefe <hholzgra@php.net>                       |
// +----------------------------------------------------------------------+
//
// $Id: Global.php,v 1.1 2004/04/01 18:43:26 hholzgra Exp $
//

/**
 * Class describing a PHP global within a PECL extension 
 *
 * @access public
 */
class PECL_Gen_Element_Global 
  extends PECL_Gen_Element 
{
    // TODO add description and use it for C code comments

    /**
     * The name of the global
     *
     * @access private
     * @var     string
     */
    var $name;
    
    /**
     * Set method for name
     *
     * @access public
     * @var string global variable name
     */
    function set_name($name) 
    {
        if (!self::is_name($name)) {
            return $this->raise_error("'$name' is not a valid global name");
        }
        
        $this->name = $name;
        
        return true;
    }
    



    /**
     * The type of the global
     *
     * @access private
     * @var     string
     */
    var $type;
    
    /**
     * Set method for name
     *
     * @access public
     * @var string C type name
     */
    function set_type($name)
    {
        if (!self::is_type($name)) {
            return $this->raiseError("'$name' is not a valid type for a global");
        }
        
        $this->type = $name;
        
        return true;
    }
    
    
    /**
     * Default value
     *
     * @access private
     * @var     string
     */
    var $value;

    /**
     * Set method for default value
     *
     * @access public
     * @param string default value 
     */
    function set_value($value)
    {
        // TODO checks
        $this->value = $value;
        
        return true;
    }
    



    /**
     * Overriding type check as we deal with real C types here
     *
     * @access public
     * @var string C type specifier
     */
    function is_type($type) 
    {
        /* check is rather naive as it doesn't know about context
           so we check for a sequence of valid names for now
           TODO: check for either simple type, struct/class or single word (typedef)
        */
        $array = explode(" ", str_replace('*',' ',$type));
        foreach ($array as $name) {
            if (empty($name)) continue;
            if (!$this->is_name($name)) return false;
        }
        return true;
    }
  
  
  
    /**
     * Generate header for global variable registration code
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    static function c_code_header($name) 
    { 
        return "static void php_{$name}_init_globals(zend_{$name}_globals *{$name}_globals)\n{\n";
    }

    /**
     * Generate registration code for this global variable
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    function c_code($name) 
    {
        $code = "  {$name}_globals->{$this->name} = ";
        if (strstr($this->type, "*")) {
            $code .= "NULL;\n";
        } else {
            $code .= "0;\n";
        }
        return $code;
    }
  
    /**
     * Generate footer for global variable registration code
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    static function c_code_footer($name) 
    {
        return '
}

static void php_'.$name.'_shutdown_globals(zend_'.$name.'_globals *'.$name.'_globals)
{
}';
    }


    /**
     * Generate header for global variable registration code in header file
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    static function h_code_header($name) 
    {
        return "ZEND_BEGIN_MODULE_GLOBALS({$name})\n";
     }

    /**
     * Generate declaration for this global variable in header file
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    function h_code($name) 
    {
        return "  {$this->type} {$this->name};\n";
    }

    /**
     * Generate footer for global variable registration code in header file
     *
     * @access private
     * @param  string extension basename
     * @return string C code snippet 
     */
    static function h_code_footer($name) 
    {
        $upname = strtoupper($name);
    
        return "
ZEND_END_MODULE_GLOBALS({$name})

#ifdef ZTS
#define {$upname}_G(v) TSRMG({$name}_globals_id, zend_{$name}_globals *, v)
#else
#define {$upname}_G(v) ({$name}_globals.v)
#endif

";
      
    }
  
    /**
     * Globals are real internals, no documentation needed
     *
     * @access public
     * @param  string id basename for extension
     * @return string empty
     */  
    function docbook_xml($base) 
    {
        return "";
    }
}

?>
